==> hubzero-cms-1.2.1_1.2.1.3.orig.tar.gz: hubzero-cms-1.2.1-1.2.1.3/cms/plugins/content/collect/views/metadata/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$url = JRequest::getVar('REQUEST_URI', '', 'server');
if (!$url)
{
	$url = JRoute::_('index.php?option=com_content&id=' . $this->article->alias);
}
?>

<p id="fav" class="fav">
	<a id="fav-this" class="collect" href="<?php echo $url . '?action=collect'; ?>">
		<?php echo JText::_('PLG_CONTENT_COLLECT_ACTION'); ?>
	</a>
</p>

==> hubzero-cms-1.3.0_1.3.0.36.orig.tar.gz: hubzero-cms-1.3.0-1.3.0.36/cms/plugins/content/collect/views/metadata/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$url = JRequest::getVar('REQUEST_URI', '', 'server');
if (!$url)
{
	$url = JRoute::_('index.php?option=com_content&id=' . $this->article->alias);
}

$foo = \JFactory::getEditor()->display('description', '', '', '', 35, 5, false, 'field_description', null, null, array('class' => 'minimal no-footer'));
?>

<p id="fav" class="fav">
	<a id="fav-this" class="collect" href="<?php echo $url . '?action=collect'; ?>">
		<?php echo JText::_('PLG_CONTENT_COLLECT_ACTION'); ?>
	</a>
</p>
